@@ -2,5 +2,5 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-from ssht00ls.v1.classes.ssh import ssh, sshfs, scp, agent, key, installation, config
+from ssht00ls.v1.classes.ssh import ssh, sshfs, scp, agent, key, installation, config, sshd
 from ssht00ls.v1.classes.smart_cards import smart_cards, SmartCard
