@@ -91,7 +91,9 @@ class SmartCards(object):
 			return r3sponse.error_response("There are no smart cards plugged in / detected.")
 
 		# success.
-		return r3sponse.success_response("There is only one smart cards plugged in.")
+		return r3sponse.success_response("There is only one smart cards plugged in.", {
+			"smart_card":l_response["smart_cards"][list(l_response["smart_cards"].keys())[0]],
+		})
 
 # the smart card class.
 class SmartCard(object):
