@@ -860,7 +860,7 @@ class Agent(object):
 		# default timeout (do not use).
 		timeout=0.5,
 		# reattempt (do not use).
-		reattempt=False,
+		reattempt=True,
 	):
 
 		# initialize.
@@ -885,15 +885,23 @@ class Agent(object):
 		if "Failed to communicate" in output or "agent refused operation" in output or "Error connecting to agent" in output or "Connection refused" in output:
 			if reattempt:
 				try:
-					output = subprocess.check_output([f"ssh-add", "-D"])
+					output = utils.__execute__([f"ssh-add", "-D"])
 					print("delete output:",output)
 				except: a=1
 				try:
-					output = subprocess.check_output([f"ssh-add", "-k"])
+					output = utils.__execute__([f"ssh-add", "-k"])
 					print("kill output:",output)
 				except: a=1
 				try:
-					output = subprocess.check_output([f"eval", "`ssh-agent`"])
+					output = utils.__execute__script_(f"eval `ssh-agent`", shell=True)
+					try: 
+						SSH_AUTH_SOCK = output.split("SSH_AUTH_SOCK=")[1].split(";")[0]
+						os.environ["SSH_AUTH_SOCK"] = SSH_AUTH_SOCK
+					except: a=1
+					try: 
+						SSH_AGENT_PID = output.split("SSH_AGENT_PID=")[1].split(";")[0]
+						os.environ["SSH_AGENT_PID"] = SSH_AGENT_PID
+					except: a=1
 					print("restart output:",output)
 				except: a=1
 				return self.add(
